@@ -142,6 +142,14 @@ static const LV2_Descriptor descriptor = {
   extension_data
 };
 
+// fix for -fvisibility=hidden
+#undef LV2_SYMBOL_EXPORT
+#ifdef _WIN32
+#    define LV2_SYMBOL_EXPORT __declspec(dllexport)
+#else
+#    define LV2_SYMBOL_EXPORT  __attribute__ ((visibility ("default")))
+#endif
+
 LV2_SYMBOL_EXPORT
 const LV2_Descriptor*
 lv2_descriptor(uint32_t index)
@@ -154,7 +162,7 @@ lv2_descriptor(uint32_t index)
   }
 }
 
-void useMIDIControlFunction (void *m, char * cfname, void (* f) (void *d, unsigned char), void *d) { }
-int getConfigParameter_dr (char * par, ConfigContext * cfg, double * dp, double lowInc, double highInc) { return 0; }
-int getConfigParameter_d (char * par, ConfigContext * cfg, double * dp) { return 0; }
+void useMIDIControlFunction (void *m, const char * cfname, void (* f) (void *d, unsigned char), void *d) { }
+int getConfigParameter_dr (const char * par, ConfigContext * cfg, double * dp, double lowInc, double highInc) { return 0; }
+int getConfigParameter_d (const char * par, ConfigContext * cfg, double * dp) { return 0; }
 /* vi:set ts=8 sts=2 sw=2: */
