@@ -1,7 +1,7 @@
 /* setBfree - DSP tonewheel organ
  *
  * Copyright (C) 2003-2004 Fredrik Kilander <fk@dsv.su.se>
- * Copyright (C) 2008-2012 Robin Gareus <robin@gareus.org>
+ * Copyright (C) 2008-2015 Robin Gareus <robin@gareus.org>
  * Copyright (C) 2012 Will Panther <pantherb@setbfree.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -18,10 +18,16 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#define _XOPEN_SOURCE 700
+
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
 
+#ifdef _WIN32
+#include <windows.h>
+#endif
+
 #include "pgmParser.h"
 #include "program.h"
 
@@ -43,15 +49,15 @@
 #define SYMBOLSIZE     STRINGBUFFERSZ
 #define VALUESIZE      STRINGBUFFERSZ
 
-typedef int TokenType;
+typedef int B3TokenType;
 typedef int ParseReturnCode;
 
 typedef struct _parserstate {
   void * p;
-  char * fileName;
+  const char * fileName;
   FILE * fp;
   int    lineNumber;
-  TokenType nextToken;
+  B3TokenType nextToken;
   char stringBuffer [STRINGBUFFERSZ];
 } ParserState;
 
@@ -74,7 +80,7 @@ typedef struct _parserstate {
 static int getToken (FILE * fp, int * linePtr, char * tokbuf, size_t tblen)
 {
   int c;
-  int tp = 0;
+  size_t tp = 0;
   int tokType = TKN_VOID;
   int state = 1;
 
@@ -173,7 +179,7 @@ static int getToken (FILE * fp, int * linePtr, char * tokbuf, size_t tblen)
  * Retrieves the next token from the input file and puts it in the parser
  * state.
  */
-static TokenType getNextToken (ParserState * ps) {
+static B3TokenType getNextToken (ParserState * ps) {
   return ps->nextToken = getToken (ps->fp,
 				   &(ps->lineNumber),
 				   ps->stringBuffer,
@@ -183,7 +189,7 @@ static TokenType getNextToken (ParserState * ps) {
 /*
  * Idempotent predicate: does the next token match the parameter?
  */
-static int nextTokenMatches (ParserState * ps, TokenType t) {
+static int nextTokenMatches (ParserState * ps, B3TokenType t) {
   return ps->nextToken == t;
 }
 
@@ -244,7 +250,7 @@ static ParseReturnCode parseExpression (ParserState * ps, char * value) {
  */
 static ParseReturnCode stateMessage (ParserState * ps,
 				     ParseReturnCode code,
-				     char * msg) {
+				     const char * msg) {
   if (code == P_WARNING) {
     fprintf(stderr, "WARNING : ");
   }
@@ -259,7 +265,7 @@ static ParseReturnCode stateMessage (ParserState * ps,
  * Parses a list of programme property assignments and sends each to the
  * application via a call to bindToProgram(...);
  */
-static ParseReturnCode parseAssignmentList (ParserState * ps, int pgmNr) {
+static ParseReturnCode parseAssignmentList (ParserState * ps, const int pgmNr) {
   ParseReturnCode R;
   char symbol[SYMBOLSIZE];
   char value[VALUESIZE];
@@ -346,22 +352,38 @@ int loadProgrammeFile (void *p, char * fileName) {
   }
 }
 
-#ifndef PRG_MAIN
+#ifdef LV2SYNTH
 int loadProgrammeString (void *p, char * pdef) {
   ParserState ps;
   ps.p = p;
-  if ((ps.fp = fmemopen (pdef, strlen(pdef), "r")) != NULL) {
-    int rtn;
+  int rv = (int) P_ERROR;
+#ifdef _WIN32
+  char temppath[MAX_PATH - 13];
+  char filename[MAX_PATH + 1];
+  if (0 == GetTempPath(sizeof(temppath), temppath))
+    return rv;
+  if (0 == GetTempFileName(temppath, "sbfpgm", 0, filename))
+    return rv;
+  FILE *f = fopen(filename, "wb");
+  if (NULL == f)
+    return rv;
+  fwrite(pdef, strlen(pdef), 1, f);
+  fclose(f);
+  if ((ps.fp = fopen(filename, "rb")) != NULL)
+#else
+  if ((ps.fp = fmemopen (pdef, strlen(pdef), "r")) != NULL)
+#endif
+  {
     ps.fileName = "<string-pipe>";
     ps.lineNumber = 0;
     getNextToken (&ps);
-    rtn = (int) parseProgramDefinitionList (&ps);
+    rv = (int) parseProgramDefinitionList (&ps);
     fclose (ps.fp);
-    return rtn;
-  }
-  else {
-    return (int) P_ERROR;
   }
+#ifdef _WIN32
+  unlink(filename);
+#endif
+  return rv;
 }
 #endif
 /* vi:set ts=8 sts=2 sw=2: */
